Constrained Boxes Example
===============================================================================

:download:`boxes.enaml <../../../examples/constrained/boxes.enaml>`

.. literalinclude:: ../../../examples/constrained/boxes.enaml
    :language: python

::

 $ enaml-run boxes.enaml

.. image:: images/boxes0.png

.. image:: images/boxes1.png
